@@ -13,26 +13,32 @@
 #' Sample size if \code{data} provided is a correlation matrix
 #'
 #' @param uni.method Character.
-#' What unidimensionality method should be used?
-#' Defaults to \code{"LE"}.
+#' What unidimensionality method should be used? 
+#' Defaults to \code{"louvain"}.
 #' Current options are:
-#'
+#' 
 #' \itemize{
 #'
 #' \item{\strong{\code{expand}}}
 #' {Expands the correlation matrix with four variables correlated .50.
-#' If number of dimension returns 2 or less in check, then the data
+#' If number of dimension returns 2 or less in check, then the data 
 #' are unidimensional; otherwise, regular EGA with no matrix
 #' expansion is used. This is the method used in the Golino et al. (2020)
 #' \emph{Psychological Methods} simulation.}
 #'
 #' \item{\strong{\code{LE}}}
-#' {Applies the leading eigenvalue algorithm (\code{\link[igraph]{cluster_leading_eigen}})
+#' {Applies the Leading Eigenvalue algorithm (\code{\link[igraph]{cluster_leading_eigen}})
 #' on the empirical correlation matrix. If the number of dimensions is 1,
-#' then the leading eigenvalue solution is used; otherwise, regular EGA
+#' then the Leading Eigenvalue solution is used; otherwise, regular EGA
 #' is used. This is the final method used in the Christensen, Garrido,
 #' and Golino (2021) simulation.}
-#'
+#' 
+#' \item{\strong{\code{louvain}}}
+#' {Applies the Louvain algorithm (\code{\link[igraph]{cluster_louvain}})
+#' on the empirical correlation matrix using a resolution parameter = 0.95.
+#' If the number of dimensions is 1, then the Louvain solution is used; otherwise,
+#' regular EGA is used. This method was validated in the Christensen (2022) simulation.}
+#' 
 #' }
 #'
 #' @param iter Numeric integer.
@@ -58,7 +64,9 @@
 #' @param seed Numeric.
 #' Seed to reproduce results. Defaults to \code{1234}. For random results, set to \code{NULL}
 #'
-#' @param corr Type of correlation matrix to compute. The default uses \code{\link[qgraph]{cor_auto}}.
+#' @param corr Character.
+#' Type of correlation matrix to compute. The default uses \code{\link[qgraph]{cor_auto}}.
+#' 
 #' Current options are:
 #'
 #' \itemize{
@@ -75,6 +83,28 @@
 #' {Computes Spearman's correlation coefficient using the pairwise complete observations via
 #' the \code{\link[stats]{cor}}} function.
 #' }
+#' 
+#' @param EGA.type Character.
+#' Type of EGA model to use.
+#' 
+#' Current options are:
+#' 
+#' \itemize{
+#' 
+#' \item{\code{\link[EGAnet]{EGA}}}
+#' {Uses standard exploratory graph analysis}
+#' 
+#' \item{\code{\link[EGAnet]{EGA.fit}}}
+#' {Uses \code{\link[EGAnet]{tefi}} to determine best fit of
+#' \code{\link[EGAnet]{EGA}}}
+#' 
+#' \item{\code{\link[EGAnet]{hierEGA}}}
+#' {Uses hierarhical exploratory graph analysis}
+#' 
+#' \item{\code{\link[EGAnet]{riEGA}}}
+#' {Uses random-intercept exploratory graph analysis}
+#' 
+#' }
 #'
 #' @param model Character.
 #' A string indicating the method to use.
@@ -98,21 +128,60 @@
 #' or \code{\link[EGAnet]{TMFG}}
 #'
 #' @param algorithm A string indicating the algorithm to use or a function from \code{\link{igraph}}
+#' Defaults to \code{"walktrap"}.
 #' Current options are:
 #'
 #' \itemize{
 #'
 #' \item{\strong{\code{walktrap}}}
 #' {Computes the Walktrap algorithm using \code{\link[igraph]{cluster_walktrap}}}
+#' 
+#' \item{\strong{\code{leiden}}}
+#' {Computes the Leiden algorithm using \code{\link[igraph]{cluster_leiden}}.
+#' Defaults to \code{objective_function = "modularity"}}
 #'
 #' \item{\strong{\code{louvain}}}
-#' {Computes the Walktrap algorithm using \code{\link[igraph]{cluster_louvain}}}
+#' {Computes the Louvain algorithm using \code{\link[igraph]{cluster_louvain}}}
 #'
 #' }
 #'
 #' @param algorithm.args List.
 #' A list of additional arguments for \code{\link[igraph]{cluster_walktrap}}, \code{\link[igraph]{cluster_louvain}},
 #' or some other community detection algorithm function (see examples)
+#' 
+#' @param consensus.iter Numeric.
+#' Number of iterations to perform in consensus clustering for the Louvain algorithm
+#' (see Lancichinetti & Fortunato, 2012).
+#' Defaults to \code{100}
+#' 
+#' @param consensus.method Character.
+#' What consensus clustering method should be used? 
+#' Defaults to \code{"highest_modularity"}.
+#' Current options are:
+#' 
+#' \itemize{
+#' 
+#' \item{\strong{\code{highest_modularity}}}
+#' {Uses the community solution that achieves the highest modularity
+#' across iterations}
+#' 
+#' \item{\strong{\code{most_common}}}
+#' {Uses the community solution that is found the most
+#' across iterations}
+#' 
+#' \item{\strong{\code{iterative}}}
+#' {Identifies the most common community solutions across iterations
+#' and determines how often nodes appear in the same community together.
+#' A threshold of 0.30 is used to set low proportions to zero.
+#' This process repeats iteratively until all nodes have a proportion of
+#' 1 in the community solution.
+#' }
+#' 
+#' \item{\code{lowest_tefi}}
+#' {Uses the community solution that achieves the lowest \code{\link[EGAnet]{tefi}}
+#' across iterations}
+#' 
+#' }
 #'
 #' @param typicalStructure Boolean.
 #' If \code{TRUE}, returns the typical network of partial correlations
@@ -126,23 +195,10 @@
 #' and its estimated dimensions.
 #' Defaults to \code{TRUE}
 #'
-#' @param plot.type Character.
-#' Plot system to use.
-#' Current options are \code{\link[qgraph]{qgraph}} and \code{\link{GGally}}.
-#' Defaults to \code{"GGally"}.
-#'
 #' @param plot.args List.
 #' A list of additional arguments for the network plot.
-#' For \code{plot.type = "qgraph"}:
-#'
-#' \itemize{
-#'
-#' \item{\strong{\code{vsize}}}
-#' {Size of the nodes. Defaults to 6.}
-#'
-#'}
-#' For \code{plot.type = "GGally"} (see \code{\link[GGally]{ggnet2}} for
-#' full list of arguments):
+#' See \code{\link[GGally]{ggnet2}} for
+#' full list of arguments:
 #'
 #' \itemize{
 #'
@@ -221,24 +277,55 @@
 #' # Load data
 #' wmt <- wmt2[,7:24]
 #'
-#' \donttest{# bootEGA glasso example
-#' ## plot.type = "qqraph" used for CRAN checks
-#' ## plot.type = "GGally" is the default
-#' boot.wmt <- bootEGA(data = wmt, iter = 500, plot.type = "qgraph",
-#' type = "parametric", ncores = 2)
+#' \donttest{# Standard EGA example
+#' boot.wmt <- bootEGA(
+#'   data = wmt, iter = 100, # recommended 500
+#'   plot.typicalStructure = FALSE, # No plot for CRAN checks
+#'   type = "parametric", ncores = 2
+#' )
+#' 
+#' # Produce Methods section
+#' methods.section(boot.wmt)
+#' 
+#' # Louvain example
+#' boot.wmt.louvain <- bootEGA(
+#'   data = wmt, iter = 100, # recommended 500
+#'   algorithm = "louvain",
+#'   plot.typicalStructure = FALSE, # No plot for CRAN checks
+#'   type = "parametric", ncores = 2
+#' )
+#' 
+#' # Spinglass example
+#' boot.wmt.spinglass <- bootEGA(
+#'   data = wmt, iter = 100, # recommended 500
+#'   algorithm = igraph::cluster_spinglass, # use any function from {igraph}
+#'   plot.typicalStructure = FALSE, # No plot for CRAN checks
+#'   type = "parametric", ncores = 2
+#' )
 #'
-#' # bootEGA TMFG example
-#' boot.wmt <- bootEGA(data = wmt, iter = 500, model = "TMFG",
-#' plot.type = "qgraph", type = "parametric", ncores = 2, seed = 1234)
-#'
-#' # bootEGA Louvain example
-#' boot.wmt <- bootEGA(data = wmt, iter = 500, algorithm = "louvain",
-#' plot.type = "qgraph", type = "parametric", ncores = 2, seed = 1234)
-#'
-#' # bootEGA Spinglass example
-#' boot.wmt <- bootEGA(data = wmt, iter = 500, model = "TMFG", plot.type = "qgraph",
-#' algorithm = igraph::cluster_spinglass, type = "parametric", ncores = 2)
-#' }
+#' # EGA fit example
+#' boot.wmt.fit <- bootEGA(
+#'   data = wmt, iter = 100, # recommended 500
+#'   EGA.type = "EGA.fit",
+#'   plot.typicalStructure = FALSE, # No plot for CRAN checks
+#'   type = "parametric", ncores = 2
+#' )
+#' 
+#' # Hierarchical EGA example
+#' boot.wmt.hier <- bootEGA(
+#'   data = wmt, iter = 100, # recommended 500
+#'   EGA.type = "hierEGA",
+#'   plot.typicalStructure = FALSE, # No plot for CRAN checks
+#'   type = "parametric", ncores = 2
+#' )
+#' 
+#' # Random-intercept EGA example
+#' boot.wmt.ri <- bootEGA(
+#'   data = wmt, iter = 100, # recommended 500
+#'   EGA.type = "riEGA",
+#'   plot.typicalStructure = FALSE, # No plot for CRAN checks
+#'   type = "parametric", ncores = 2
+#' )}
 #'
 #' @references
 #' # Original implementation of bootEGA \cr
@@ -255,24 +342,34 @@
 #' and \code{\link[EGAnet]{CFA}} to verify the fit of the structure suggested by EGA using confirmatory factor analysis.
 #'
 #' @importFrom stats cov median sd qt quantile
+#' @importFrom methods formalArgs
 #'
 #' @export
 #'
 # Bootstrap EGA
-# Updated 05.11.2021
-bootEGA <- function(data, n = NULL, uni.method = c("expand", "LE"), iter,
-                    type = c("parametric", "resampling"), seed = 1234,
-                    corr = c("cor_auto", "pearson", "spearman"),
-                    model = c("glasso", "TMFG"), model.args = list(),
-                    algorithm = c("walktrap", "louvain"), algorithm.args = list(),
-                    typicalStructure = TRUE, plot.typicalStructure = TRUE,
-                    plot.type = c("GGally", "qgraph"),
-                    plot.args = list(), ncores, ...) {
+# Updated 18.07.2022
+bootEGA <- function(
+    data, n = NULL, uni.method = c("expand", "LE", "louvain"), iter,
+    type = c("parametric", "resampling"), seed = 1234,
+    corr = c("cor_auto", "pearson", "spearman"),
+    EGA.type = c("EGA", "EGA.fit", "hierEGA", "riEGA"),
+    model = c("glasso", "TMFG"), model.args = list(),
+    algorithm = c("walktrap", "leiden", "louvain"), algorithm.args = list(),
+    consensus.method = c(
+      "highest_modularity",
+      "most_common",
+      "iterative",
+      "lowest_tefi"
+    ), consensus.iter = 100,
+    typicalStructure = TRUE, plot.typicalStructure = TRUE,
+    plot.args = list(), ncores, ...
+) 
+{
   
   # Make data a matrix
   data <- as.matrix(data)
 
-  #### DEPRECATED ARGUMENTS ####
+  #### DEPRECATED ARGUMENTS
 
   # Get additional arguments
   add.args <- list(...)
@@ -301,12 +398,7 @@ bootEGA <- function(data, n = NULL, uni.method = c("expand", "LE"), iter,
     )
   }
 
-  #### DEPRECATED ARGUMENTS ####
-
-  # Message function
-  message(styletext(styletext("\nBootstrap Exploratory Graph Analysis\n", defaults = "underline"), defaults = "bold"))
-
-  #### MISSING ARGUMENTS HANDLING ####
+  #### MISSING ARGUMENTS HANDLING
 
   if(missing(uni.method)){
     uni.method <- "LE"
@@ -315,63 +407,40 @@ bootEGA <- function(data, n = NULL, uni.method = c("expand", "LE"), iter,
   if(missing(corr)){
     corr <- "cor_auto"
   }else{corr <- match.arg(corr)}
+  
+  if(missing(EGA.type)){
+    EGA.type <- "EGA"
+  }else{EGA.type <- match.arg(EGA.type)}
 
   if(missing(model)){
     model <- "glasso"
-  }else{
-    model <- match.arg(model)
-  }
+  }else{model <- match.arg(model)}
 
   if(missing(algorithm)){
     algorithm <- "walktrap"
   }else if(!is.function(algorithm)){
     algorithm <- match.arg(algorithm)
+  }else{
+    algorithm <- algorithm
   }
 
   if(missing(type)){
     type <- "parametric"
-  }else{
-    type <- match.arg(type)
-  }
+  }else{type <- match.arg(type)}
+  
+  if(missing(consensus.method)){
+    consensus.method <- "most_common"
+  }else{consensus.method <- tolower(match.arg(consensus.method))}
+  
 
   if(missing(ncores)){
     ncores <- ceiling(parallel::detectCores() / 2)
   }
 
-  if(missing(plot.type)){
-    plot.type <- "GGally"
-  }else{
-    plot.type <- match.arg(plot.type)
-  }
-
   ## Check for input plot arguments
-  color.palette <- "polychrome"
-
-  #### MISSING ARGUMENTS HANDLING ####
-
-  # Let user know setting
-  message(paste(" \u2022 type = ", type, "\n",
-                " \u2022 iterations = ", iter, "\n",
-                " \u2022 model = ", model, "\n",
-                " \u2022 algorithm = ",
-                gsub(
-                  "igraph", "",
-                  gsub(
-                    "::", "",
-                    gsub(
-                      "cluster_", "",
-                      paste(substitute(algorithm), collapse = "")
-                    )
-                  )
-                ),
-                "\n",
-                " \u2022 correlation = ", corr, "\n",
-                " \u2022 unidimensional check = ", ifelse(
-                  uni.method == "LE",
-                  "leading eigenvalue",
-                  "correlation matrix expansion"
-                ), "\n",
-                sep=""))
+  if("color.palette" %in% names(plot.args)){
+    color.palette <- plot.args$color.palette
+  }else{color.palette <- "polychrome"}
 
   #number of cases
   if(is.null(n)){
@@ -385,18 +454,67 @@ bootEGA <- function(data, n = NULL, uni.method = c("expand", "LE"), iter,
   }else{
     cases <- n
   }
-
-  #empirical EGA
-  empirical.EGA <- suppressMessages(suppressWarnings(EGA(data = data, n = cases, uni.method = uni.method, corr = corr,
-                                                         model = model, model.args = model.args,
-                                                         algorithm = algorithm, algorith.args = algorithm.args,
-                                                         plot.EGA = FALSE)))
+  
+  # Obtain EGA function
+  ega_function <- switch(
+    tolower(EGA.type),
+    "ega" = EGA,
+    "ega.fit" = EGA.fit,
+    "hierega" = hierEGA,
+    "riega" = riEGA
+  )
+  
+  # EGA calls
+  ega_args <- list(
+    data = data, n = cases, uni.method = uni.method,
+    corr = corr, model = model, model.args = model.args,
+    algorithm = algorithm, algorithm.args = algorithm.args,
+    consensus.method = consensus.method,
+    consensus.iter = consensus.iter,
+    plot.EGA = FALSE
+  )
+  
+  # Remove calls that are not in formal arguments
+  ega_args <- ega_args[
+    !is.na(
+      match(names(ega_args), formalArgs(ega_function))
+    )
+  ]
+  
+  # Estimate empirical EGA (run quietly)
+  empirical_EGA <- suppressWarnings(
+    suppressMessages(
+      do.call(
+        ega_function, ega_args
+      )
+    )
+  )
+  
+  # EGA output
+  if("EGA" %in% names(empirical_EGA)){
+    # Obtain EGA output from EGA option 
+    ega_output <- empirical_EGA$EGA
+  }else if(!is(empirical_EGA, "EGA")){
+    
+    # Base on EGA type
+    if(tolower(EGA.type) == "hierega"){
+      
+      # Obtain lower order output
+      ega_output <- empirical_EGA$hierarchical$lower_order
+      
+    }
+    
+  }else{
+    # Assume output is from standard EGA
+    ega_output <- empirical_EGA
+  }
+  
 
   #set inverse covariance matrix for parametric approach
   if(type == "parametric"){  # Use a parametric approach
 
     ## Compute correlation matrix
-    cor.data <- empirical.EGA$correlation
+    cor.data <- ega_output$correlation
 
     # Generating data will be continuous
     corr.method <- "pearson"
@@ -458,11 +576,11 @@ bootEGA <- function(data, n = NULL, uni.method = c("expand", "LE"), iter,
   cl <- parallel::makeCluster(ncores)
 
   # #Export variables
-  # parallel::clusterExport(cl = cl,
-  #                         varlist = c("datalist", "uni.method", "cases", "corr",
-  #                                     "model", "model.args",
-  #                                     "algorithm", "algorithm.args"),
-  #                         envir=environment())
+  parallel::clusterExport(
+    cl = cl,
+    varlist = c("ega_function", "ega_args"),
+    envir=environment()
+  )
 
   #let user know data generation has started
   message("Estimating EGA networks...\n", appendLF = FALSE)
@@ -470,20 +588,44 @@ bootEGA <- function(data, n = NULL, uni.method = c("expand", "LE"), iter,
   #Estimate networks
   boots <- pbapply::pblapply(
     X = datalist, cl = cl,
-    FUN = EGA,
-    uni.method = uni.method, corr = corr.method,
-    model = model, model.args = model.args,
-    algorithm = algorithm, algorith.args = algorithm.args,
-    plot.EGA = FALSE
+    FUN = function(x){
+      do.call(ega_function, ega_args)
+    }
   )
 
   parallel::stopCluster(cl)
+  
+  # Bootstrap output
+  if("EGA" %in% names(boots[[1]])){
+    # Obtain EGA output from EGA option 
+    boot_output <- lapply(boots, function(x){
+      x$EGA
+    })
+  }else if(!is(boots[[1]], "EGA")){
+    
+    # Base on EGA type
+    if(tolower(EGA.type) == "hierega"){
+      
+      # Obtain lower order output
+      boot_output <- lapply(boots, function(x){
+        x$hierarchical$lower_order
+      })
+      boot_output_higher <- lapply(boots, function(x){
+        x$hierarchical$higher_order$EGA
+      })
+      
+    }
+    
+  }else{
+    # Assume output is from standard EGA
+    boot_output <- boots
+  }
 
   #let user know results are being computed
   message("Computing results...\n")
 
   #get networks
-  bootGraphs <- lapply(boots, function(x, col.names){
+  bootGraphs <- lapply(boot_output, function(x, col.names){
     net <- x$network
     colnames(net) <- col.names
     row.names(net) <- col.names
@@ -491,7 +633,7 @@ bootEGA <- function(data, n = NULL, uni.method = c("expand", "LE"), iter,
   }, col.names = colnames(data))
 
   #get community membership
-  boot.wc <- lapply(boots, function(x, col.names){
+  boot.wc <- lapply(boot_output, function(x, col.names){
     wc <- x$wc
     names(wc) <- col.names
     return(wc)
@@ -503,26 +645,32 @@ bootEGA <- function(data, n = NULL, uni.method = c("expand", "LE"), iter,
 
   boot.ndim[,1] <- seq_len(iter)
   boot.ndim[,2] <- unlist(
-    lapply(boots, function(x){
+    lapply(boot_output, function(x){
       x$n.dim
     })
   )
 
   if (typicalStructure){
 
-    typical.Structure <- switch(model,
-                                "glasso" = apply(simplify2array(bootGraphs),1:2, median),
-                                "TMFG" = apply(simplify2array(bootGraphs),1:2, mean)
-                         )
+    typical.Structure <- switch(
+      model,
+      "glasso" = apply(simplify2array(bootGraphs),1:2, median),
+      "TMFG" = apply(simplify2array(bootGraphs),1:2, mean)
+      
+    )
 
-    # Sub-routine to following EGA approach (handles undimensional structures)
+    # Sub-routine to following EGA approach (handles unidimensional structures)
     typical.wc <- suppressWarnings(
       suppressMessages(
 
-        typicalStructure.network(A = typical.Structure, corr = corr,
-                                 model = model, model.args = model.args,
-                                 n = cases, uni.method = uni.method, algorithm = algorithm,
-                                 algorithm.args = algorithm.args)
+        typicalStructure.network(
+          A = typical.Structure, corr = corr,
+          model = model, model.args = model.args,
+          n = cases, uni.method = uni.method, algorithm = algorithm,
+          algorithm.args = algorithm.args,
+          consensus.method = consensus.method,
+          consensus.iter = consensus.iter
+        )
 
       )
     )
@@ -551,44 +699,201 @@ bootEGA <- function(data, n = NULL, uni.method = c("expand", "LE"), iter,
   colnames(lik) <- c("# of Factors", "Frequency")
   count <- 0
 
-  for(i in seq(from=min(dim.range),to=max(dim.range),by=1))
-  {
+  for(i in seq(from=min(dim.range),to=max(dim.range),by=1)){
     count <- count + 1
     lik[count,1] <- i
     lik[count,2] <- length(which(boot.ndim[,2]==i))/iter
   }
   
+  # Higher order EGA
+  if(tolower(EGA.type) == "hierega"){
+    
+    #get networks
+    bootGraphs_higher <- lapply(boot_output_higher, function(x){
+      net <- x$network
+      return(net)
+    })
+    
+    #get community membership
+    boot.wc_higher <- lapply(boot_output_higher, function(x){
+      wc <- x$wc
+      return(wc)
+    })
+    
+    #get dimensions
+    boot.ndim_higher <- matrix(NA, nrow = iter, ncol = 2)
+    colnames(boot.ndim_higher) <- c("Boot.Number", "N.Dim")
+    
+    boot.ndim_higher[,1] <- seq_len(iter)
+    boot.ndim_higher[,2] <- unlist(
+      lapply(boot_output_higher, function(x){
+        x$n.dim
+      })
+    )
+    
+    if (typicalStructure){
+      
+      typical.Structure_higher <- switch(model,
+                                  "glasso" = apply(simplify2array(bootGraphs_higher),1:2, median),
+                                  "TMFG" = apply(simplify2array(bootGraphs_higher),1:2, mean)
+      )
+      
+      # Sub-routine to following EGA approach (handles undimensional structures)
+      typical.wc_higher <- suppressWarnings(
+        suppressMessages(
+          
+          typicalStructure.network(
+            A = typical.Structure_higher, corr = corr,
+            model = model, model.args = model.args,
+            n = cases, uni.method = uni.method, algorithm = algorithm,
+            algorithm.args = algorithm.args,
+            consensus.method = consensus.method,
+            consensus.iter = consensus.iter
+          )
+          
+        )
+      )
+      
+      typical.ndim_higher <- length(na.omit(unique(typical.wc_higher)))
+      
+      if(typical.ndim_higher == 1){typical.wc_higher[1:length(typical.wc_higher)] <- 1}
+      
+      dim.variables_higher <- data.frame(items = names(typical.wc_higher), dimension = typical.wc_higher)
+    }
+    
+    Median_higher <- median(boot.ndim_higher[, 2], na.rm = TRUE)
+    se.boot_higher <- sd(boot.ndim_higher[, 2], na.rm = TRUE)
+    ciMult_higher <- qt(0.95/2 + 0.5, nrow(boot.ndim_higher) - 1)
+    ci_higher <- se.boot_higher * ciMult_higher
+    quant_higher <- quantile(boot.ndim_higher[,2], c(.025, .975), na.rm = TRUE)
+    summary.table_higher <- data.frame(n.Boots = iter, median.dim = Median_higher,
+                                SE.dim = se.boot_higher, CI.dim = ci_higher,
+                                Lower.CI = Median_higher - ci_higher, Upper.CI = Median_higher + ci_higher,
+                                Lower.Quantile = quant_higher[1], Upper.Quantile = quant_higher[2])
+    row.names(summary.table_higher) <- NULL
+    
+    #compute frequency
+    dim.range_higher <- range(boot.ndim_higher[,2], na.rm = TRUE)
+    lik_higher <- matrix(0, nrow = diff(dim.range_higher)+1, ncol = 2)
+    colnames(lik_higher) <- c("# of Factors", "Frequency")
+    count <- 0
+    
+    for(i in seq(from=min(dim.range_higher),to=max(dim.range_higher),by=1)){
+      count <- count + 1
+      lik_higher[count,1] <- i
+      lik_higher[count,2] <- length(which(boot.ndim_higher[,2]==i))/iter
+    }
+    
+  }
+  
   # Reset seed
   set.seed(NULL)
 
-  result <- list()
-  result$iter <- iter
-  result$type <- type
-  result$boot.ndim <- boot.ndim
-  result$boot.wc <- boot.wc
-  result$bootGraphs <- bootGraphs
-  result$summary.table <- summary.table
-  result$frequency <- lik
-  result$EGA <- empirical.EGA
+  # Set up result list
+  if(tolower(EGA.type) == "hierega"){
+    result <- list(
+      iter = iter, type = type, boot.ndim = boot.ndim,
+      boot.wc = boot.wc, bootGraphs = bootGraphs,
+      summary.table = summary.table, frequency = lik,
+      EGA = empirical_EGA, EGA.type = EGA.type
+    )
+  }else{
+    result <- list(
+      iter = iter, type = type, boot.ndim = boot.ndim,
+      boot.wc = boot.wc, bootGraphs = bootGraphs,
+      summary.table = summary.table, frequency = lik,
+      EGA = ega_output, EGA.type = EGA.type
+    )
+  }
 
   # Typical structure
   if (typicalStructure) {
 
-    typicalGraph <- list()
-    typicalGraph$graph <- typical.Structure
-    typicalGraph$typical.dim.variables <- dim.variables[order(dim.variables[,2]), ]
-    typicalGraph$wc <- typical.wc
+    typicalGraph <- list(
+      graph = typical.Structure,
+      typical.dim.variables = dim.variables[order(dim.variables[,2]), ],
+      wc = typical.wc
+    )
+    
     result$typicalGraph <- typicalGraph
-
+    
+  }
+  
+  # higher order
+  if(tolower(EGA.type) == "hierega"){
+    
+    # Set up result list
+    result_higher <- list(
+      iter = iter, type = type, boot.ndim = boot.ndim_higher,
+      boot.wc = boot.wc_higher, bootGraphs = bootGraphs_higher,
+      summary.table = summary.table_higher, frequency = lik_higher
+    )
+    
+    # Typical structure
+    if (typicalStructure) {
+      
+      typicalGraph_higher <- list(
+        graph = typical.Structure_higher,
+        typical.dim.variables = dim.variables_higher[order(dim.variables_higher[,2]), ],
+        wc = typical.wc_higher
+      )
+      
+      result_higher$typicalGraph <- typicalGraph_higher
+      
+    }
+    
   }
 
   # Add plot arguments (for itemStability)
   result$color.palette <- color.palette
 
   class(result) <- "bootEGA"
+  
+  if(tolower(EGA.type) == "hierega"){
+    class(result_higher) <- "bootEGA"
+  }
 
   if(typicalStructure & plot.typicalStructure){
-    result$plot.typical.ega <- plot(result)
+    
+    if(tolower(EGA.type) != "hierega"){
+      result$plot.typical.ega <- plot(
+        result,
+        plot.args = plot.args
+      )
+    }else{
+      
+      # Set up output
+      hier_plot <- suppressMessages(
+        suppressWarnings(
+          suppressPackageStartupMessages(
+            ggpubr::ggarrange(
+              plot(
+                result,
+                plot.args = plot.args,
+                produce = FALSE
+              ), # plot lower-order
+              plot(
+                result_higher,
+                plot.args = plot.args,
+                produce = FALSE
+              ), # plot higher-order
+              labels = c("Lower Order", "Higher Order")
+            )
+          )
+        )
+      )
+      
+      # Output plots
+      result$plot.typical.ega <- suppressMessages(
+        suppressWarnings(
+          suppressPackageStartupMessages(
+            plot(hier_plot)
+          )
+        )
+      )
+      
+    }
+  
   }
 
   # Check if uni.method = "LE" has been used
@@ -612,7 +917,18 @@ bootEGA <- function(data, n = NULL, uni.method = c("expand", "LE"), iter,
       )
     )
   }
+  
+  # Set results for higher order EGA
+  if(tolower(EGA.type) == "hierega"){
+    
+    result <- list(
+      result_lower = result,
+      result_higher = result_higher
+    )
+    
+  }
 
   return(result)
+  
 }
 #----
