@@ -61,7 +61,7 @@
 #'
 #' @export
 #'
-# Updated 27.04.2022
+# Updated 16.07.2022
 ## Function to produce color palettes for EGA
 color_palette_EGA <- function (name, wc, sorted = FALSE)
 {
@@ -102,24 +102,26 @@ color_palette_EGA <- function (name, wc, sorted = FALSE)
                     )
 
   # Default palette
-  ## Polychrome (20 colors)
+  ## Polychrome (40 colors)
   polychrome <- toupper(
     paste("#",
           c("F03D2D", "90DDF0", "C8D96F", "ef8a17", "f5c900",
             "ba42c0", "17BEBB", "9bafd9", "f27a7d", "f9c58d",
             "f7f779", "c5f9d7", "a18dce", "f492f0", "919bff",
-            "c792df", "60b6f1", "f9a470", "bc556f", "f7a2a1",
-            "3a445d", "5e5768", "928779", "d4d2a5", "fcdebe",
-            "6d1a36", "bce7fd", "53917e", "dd99bb", "fcd0a1"
+            "c792df", "ff4f79", "f9a470", "bc556f", "f7a2a1",
+            "3a445d", "5e5768", "928779", "d4d2a5", "a11692",
+            "6d1a36", "bce7fd", "53917e", "dd99bb", "fcd0a1",
+            "a9fbd7", "d81159", "8f2d56", "006ba6", "39304a",
+            "ff470a", "60b6f1", "fcdebe", "cff27e", "b87d4b"
             
           ), sep = "")
   )
   
   # Check colors
-  #barplot(
-  #  1:20,
+  # barplot(
+  #  1:length(polychrome),
   #  col = polychrome
-  #)
+  # )
   
   
   ## Other palettes
