@@ -6,11 +6,11 @@
 #'
 #' @param ... \code{\link{EGAnet}} objects
 #' 
-#' @param input_list List.
+#' @param input.list List.
 #' Bypasses \code{...} argument in favor of using a list
 #' as an input
 #' 
-#' @param base_plot Numeric.
+#' @param base.plot Numeric.
 #' Plot to be used as the base for the configuration of the networks.
 #' Uses the number of the order in which the plots are input.
 #' Defaults to \code{1} or the first plot
@@ -24,11 +24,6 @@
 #' @param columns Numeric.
 #' Number of columns to spread plots down
 #' 
-#' @param plot.type Character.
-#' Plot system to use.
-#' Current options are \code{\link[qgraph]{qgraph}} and \code{\link{GGally}}.
-#' Defaults to \code{"GGally"}
-#' 
 #' @param plot.args List.
 #' A list of additional arguments for the network plot.
 #' For \code{plot.type = "qgraph"}:
@@ -38,8 +33,9 @@
 #' \item{\strong{\code{vsize}}}
 #' {Size of the nodes. Defaults to 6.}
 #'
-#'}
-#' For \code{plot.type = "GGally"} (see \code{\link[GGally]{ggnet2}} for
+#' }
+#' 
+#' (see \code{\link[GGally]{ggnet2}} for
 #' full list of arguments):
 #'
 #' \itemize{
@@ -70,27 +66,43 @@
 #' @return Visual comparison of \code{\link{EGAnet}} objects
 #' 
 #' @examples
-#' # obtain SAPA items
+#' # Obtain SAPA items
 #' items <- psychTools::spi[,c(11:20)]
 #' 
+#' # Draw random samples
+#' sample1 <- items[sample(1:nrow(items), 1000),]
+#' sample2 <- items[sample(1:nrow(items), 1000),]
+#' 
+#' \donttest{# Estimate EGAs
+#' ega1 <- EGA(sample1)
+#' ega2 <- EGA(sample2)
+#' 
+#' # Compare EGAs via plot
+#' compare.EGA.plots(
+#'   ega1, ega2,
+#'   base.plot = 1, # use "ega1" as base for comparison
+#'   labels = c("Sample 1", "Sample 2"),
+#'   rows = 1, columns = 2
+#' )}
+#' 
 #' @author Alexander Christensen <alexpaulchristensen@gmail.com>
 #'
 #' @export
 #
 # Compare EGA plots function
-# Updated 28.03.2022
+# Updated 18.07.2022
 compare.EGA.plots <- function(
-  ..., input_list = NULL,
-  base_plot = 1,
+  ..., input.list = NULL,
+  base.plot = 1,
   labels, rows, columns,
-  plot.type = c("GGally", "qgraph"), plot.args = list()
+  plot.args = list()
 )
 {
   # Check for input list
-  if(is.null(input_list)){
+  if(is.null(input.list)){
     object.list <- list(...)
   }else{
-    object.list <- input_list
+    object.list <- input.list
   }
   
   # Identify EGA objects
@@ -115,22 +127,16 @@ compare.EGA.plots <- function(
     labels <- name
   }
   
-  if(missing(plot.type)){
-    plot.type <- "GGally"
-  }else{
-    plot.type <- match.arg(plot.type)
-  }
-  
   # Check for at least two objects
   if(length(object.list) < 2){
     stop("EGA plot comparisons require two or more EGA objects")
   }
   
   # Obtain base EGA
-  base_EGA <- object.list[[base_plot]]
+  base_EGA <- object.list[[base.plot]]
   
   # Comparison EGAs
-  comparison_EGA <- object.list[-base_plot]
+  comparison_EGA <- object.list[-base.plot]
   
   # Set up number of communities (for legend later)
   num_wc <- numeric(length(object.list))
@@ -202,7 +208,6 @@ compare.EGA.plots <- function(
   plots_ega <- suppressPackageStartupMessages(
     compare.plot.fix.EGA(
       object.list,
-      plot.type = plot.type,
       plot.args = plot.args
     )
   )
@@ -220,8 +225,8 @@ compare.EGA.plots <- function(
   
   # Re-organize plot list with reference to base plot
   set_number <- 1:length(plots_ega) # obtain number of plots
-  set_diff <- setdiff(set_number, base_plot) # remove base plot
-  set_org <- c(base_plot, set_diff) # get set organization
+  set_diff <- setdiff(set_number, base.plot) # remove base plot
+  set_org <- c(base.plot, set_diff) # get set organization
   plots_ega <- plots_ega[set_org] # organize to original inputs
   
   # Set up grid return
