@@ -56,16 +56,16 @@
 #' Engle, R., & Watson, M. (1981).
 #' A one-factor multivariate time series model of metropolitan wage rates.
 #' \emph{Journal of the American Statistical Association}, \emph{76}(376), 774-781.
-#' 
+#'
 #' Nesselroade, J. R., McArdle, J. J., Aggen, S. H., & Meyers, J. M. (2002).
 #' Dynamic factor analysis models for representing process in multivariate time-series. In D. S. Moskowitz & S. L. Hershberger (Eds.),
 #' \emph{Multivariate applications book series. Modeling intraindividual variability with repeated measures data: Methods and applications}, 235-265.
-#' 
+#'
 #' @author Hudson F. Golino <hfg9s at virginia.edu>
 #'
 #' @export
 # Simulate dynamic factor model
-# Updated 26.05.2021
+# Updated 09.05.2022
 simDFM <- function(variab, timep, nfact, error, dfm = c("DAFS","RandomWalk"),
                    loadings, autoreg, crossreg, var.shock, cov.shock, burnin = 1000){
 
@@ -78,13 +78,13 @@ simDFM <- function(variab, timep, nfact, error, dfm = c("DAFS","RandomWalk"),
 
   if(dfm == "DAFS"){
     # B = Matrix of Bl is a nfact x nfact matrix containing the autoregressive and cross-regressive coefficients
-    B <- matrix(autoreg, ncol = nfact, nrow = nfact)
-    diag(B) <- crossreg
+    B <- matrix(crossreg, ncol = nfact, nrow = nfact)
+    diag(B) <- autoreg
 
     # Shock = Random shock vectors following a multivariate normal distribution with mean zeros and nfact x nfact q covariance matrix D
     D <- matrix(var.shock,nfact,nfact)
     diag(D) <- cov.shock
-    Shock <- MASS::mvrnorm(burnin+timep,matrix(0,nfact,1),D)
+    Shock <- MASS_mvrnorm(burnin+timep,matrix(0,nfact,1),D)
 
     Fscores <- matrix(0,burnin+timep,nfact)
     Fscores[1,] <- Shock[1,]
@@ -107,7 +107,7 @@ simDFM <- function(variab, timep, nfact, error, dfm = c("DAFS","RandomWalk"),
   ## Error: multivariate normal distribution with mean zeros and p x p covariance matrix Q
   var <- error^2
   Q <- diag(var,variab*nfact,variab*nfact)
-  e <- t(MASS::mvrnorm(timep, matrix(0,variab*nfact,1),Q))
+  e <- t(MASS_mvrnorm(timep, matrix(0,variab*nfact,1),Q))
 
 
   ## Simulated obs data
